import os

import lmfit as lm
import matplotlib.pyplot as plt
import numpy as np
from pytestpavement.analysis.regression import fit_cos, fit_cos_eval
from pytestpavement.helper.exceptions import HashInDb
from pytestpavement.io.geosys import read_geosys
from pytestpavement.labtests.base import DataSineLoad
from pytestpavement.models.citt import CyclicIndirectTensileTest


class CittTest(DataSineLoad):
    """
    Base Class of CyclicIndirectTensileTest
    """

    def __init__(self,
                 fname: str,
                 debug: bool = False,
                 temperature: float = -999.9):

        #set parameter
        self.file = fname
        self.temperature = temperature

        # process file
        self._run()

    def _run(self):
        self._calc_hash()
        self._file_in_db()
        self._set_parameter()
        self._define_units()

    def _file_in_db(self):

        n = CyclicIndirectTensileTest.objects(filehash=self.filehash).count()

        assert n == 0, HashInDb

    def _set_parameter(self):

        self.split_data_based_on_parameter = [
            'T', 'sigma_normal', 'f', 'extension'
        ]

        self.col_as_int = ['N']
        self.col_as_float = ['T', 'F', 'f', 's_vert_sum']

        self.val_col_names = ['time', 'T', 'f', 'N', 'F', 's_vert_sum']
        # Header names after standardization; check if exists
        self.val_header_names = ['speciment_diameter']

        self.columns_analyse = [
            'F', 's_vert_sum', 's_vert_1', 's_vert_2', 's_piston'
        ]

        self.number_of_load_cycles_for_analysis = 5
